@@ -93,6 +93,7 @@ calc_catchment <- function(
                            retainAreaProportion = FALSE,
                            dissolve = FALSE,
                            quadsegs = NULL) {
+  .Deprecated(msg = "Try using functionality in the sfnetworks package")
   UseMethod(generic = "calc_catchment")
 }
 #' @export
@@ -324,8 +325,8 @@ calc_catchment.sf <- function(
 #' data_dir <- system.file("extdata", package = "stplanr")
 #' unzip(file.path(data_dir, "smallsa1.zip"))
 #' unzip(file.path(data_dir, "testcycleway.zip"))
-#' sa1income <- readOGR(".", "smallsa1")
-#' testcycleway <- readOGR(".", "testcycleway")
+#' sa1income <- rgdal::readOGR(".", "smallsa1")
+#' testcycleway <- rgdal::readOGR(".", "testcycleway")
 #' calc_catchment_sum(
 #'   polygonlayer = sa1income,
 #'   targetlayer = testcycleway,
